<?php


namespace Controller;

use Traits\TResponse;
use Util\InstanceProvider;
use Util\Utilities;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;

class Soliserv
{
    use TResponse;

    /**
     * @var \Service\Soliserv
     */
    private $soliservService;

    public function __construct(\Service\Soliserv $soliservService)
    {
        $this->soliservService = $soliservService;
    }

    public function tarefaSoli(Request $request, Response $response)
    {
        try {
            $nrsoliserv = $request->getParameter('NRSOLISERV');
            $actions = $this->soliservService->findTarefa($nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findItemTarefa(Request $request, Response $response)
    {
        try {

            $param = $request->getParameters();
            $nrtarefa = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];
            $nrtarefa = Utilities::fixBugNextFindArrayGrid($nrtarefa);
            $nrsoliserv = empty($param['NRSOLISERV']) ? null : $param['NRSOLISERV'];
            $actions = $this->soliservService->findItemTarefa($nrtarefa,$nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findAddItemTarefa(Request $request, Response $response)
    {
        try {

            $actions = $this->soliservService->findAddItemTarefa();
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findPlanativtare(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $nrtarefas = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];

            $actions = $this->soliservService->findPlanativtare($nrtarefas);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findProcessTotalized(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $nrtarefas = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];

            $actions = $this->soliservService->findProcessTotalized($nrtarefas);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findValidadeAtividateGerada(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $nrtarefas = empty($param['NRTAREFA']) ? '': $param['NRTAREFA'];
            $cdprocessos = empty($param['CDPROCESSOS']) ? array() : $param['CDPROCESSOS'];
            $cditemtrabalhos = empty($param['CDITEMTRABALHOS']) ? array() : $param['CDITEMTRABALHOS'];
            $actions = $this->soliservService->findValidadeAtividateGerada($nrtarefas,$cdprocessos,$cditemtrabalhos);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function generateActivitiesTaskSoli(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters()['params'];
            $nrtarefa = empty($param['NRTAREFA']) ? '': $param['NRTAREFA'];
            $cdarvprocess = empty($param['CDARVPROCESS']) ? '': $param['CDARVPROCESS'];
            $nrsoliserv = empty($param['NRSOLISERV']) ? '': $param['NRSOLISERV'];
            $processos = empty($param['PROCESSES']) ? array() : $param['PROCESSES'];
            $itemtarefas = empty($param['ITEMTAREFAS']) ? array() : $param['ITEMTAREFAS'];
            $actions = $this->soliservService->generateActivitiesSoliserv($nrtarefa,$cdarvprocess,$nrsoliserv,$processos,$itemtarefas);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveItemTarefaSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params['rowsSave'] as $param) {
                $cditemtrab = empty($param['CDITEMTRAB']) ? null : $param['CDITEMTRAB'];
                $nrtarefa = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];
                $nrprioittare = empty($param['NRPRIOITTARE']) ? null : $param['NRPRIOITTARE'];
                $nrcplximplem = empty($param['NRCPLXIMPLEM']) ? "0" : $param['NRCPLXIMPLEM'];
                $nrcplxitemtb = empty($param['NRCPLXITEMTB']) ? "0" : $param['NRCPLXITEMTB'];
                $nrcplxitemtb = preg_replace('/[^0-9]/', '', $nrcplxitemtb);
                $nrcplximplem = preg_replace('/[^0-9]/', '', $nrcplximplem);
                $this->soliservService->saveItemTarefaSoli($cditemtrab, $nrtarefa, $nrprioittare, $nrcplximplem, $nrcplxitemtb);
            }

        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function editItemTarefaSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params['rowsSave'] as $param) {
                $nrtarefa = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];
                $nrsequittare = empty($param['NRSEQUITTARE']) ? null : $param['NRSEQUITTARE'];
                $nrprioittare = empty($param['NRPRIOITTARE']) ? null : $param['NRPRIOITTARE'];
                $nrcplximplem = empty($param['NRCPLXIMPLEM']) ? "0" : $param['NRCPLXIMPLEM'];
                $nrcplxitemtb = empty($param['NRCPLXITEMTB']) ? "0" : $param['NRCPLXITEMTB'];
                $nrcplxitemtb = preg_replace('/[^0-9]/', '', $nrcplxitemtb);
                $nrcplximplem = preg_replace('/[^0-9]/', '', $nrcplximplem);
                $this->soliservService->editItemTarefaSoli($nrsequittare, $nrtarefa, $nrprioittare, $nrcplximplem, $nrcplxitemtb);
            }

        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findTarefaAllResponsavel(Request $request, Response $response)
    {
        try {
            $nrsoliserv = $request->getParameter('NRSOLISERV');
            $actions = $this->soliservService->findTarefaAllResponsavel($nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findTarefaAssunto(Request $request, Response $response)
    {
        try {
            $actions = $this->soliservService->findTarefaAssunto();
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findDefaultTaskSoli(Request $request, Response $response)
    {
        try {
            $nrsoliserv = $request->getParameter('NRSOLISERV');
            $actions = $this->soliservService->findDefaultTaskSoli($nrsoliserv);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findProcessGeneration(Request $request, Response $response)
    {
        try {
            $actions = $this->soliservService->findProcessGeneration();
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }


    public function findActivitiesGeneration(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $cdarvprocess = empty($param['CDARVPROCESS']) ? null : $param['CDARVPROCESS'];
            $actions = $this->soliservService->findActivitiesGeneration($cdarvprocess);
            $this->sendResponse($actions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteTarefasSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params as $param) {
                $nrtarefa = $param['NRTAREFA'];
                $this->soliservService->deleteTarefaSoli($nrtarefa);
            }
            $this->sendResponse([], 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteItemTarefasSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params as $param) {
                $nrtarefa = $param['NRTAREFA'];
                $nrsequittare = $param['NRSEQUITTARE'];
                $this->soliservService->deleteItemTarefasSoli($nrtarefa, $nrsequittare);
            }
            $this->sendResponse([], 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteGridActivityS(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params as $param) {
                $nrtarefa = $param['NRTAREFA'];
                $cdfilial = $param['CDFILIAL'];
                $nrplativtare = $param['NRPLATIVTARE'];
                $this->soliservService->deleteGridActivityS($nrtarefa, $cdfilial, $nrplativtare);
            }
            $this->sendResponse([], 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function downloadFileSpecificationTaskS(Request $request, Response $response)
    {
        try{
            $param = $request->getParameters();
            $nrsoliserv = $param['NRSOLISERV'];
            $this->soliservService->getPageRequisite($nrsoliserv);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function insertFileSpecificationTaskS(Request $request, Response $response)
    {
        try{
            $param = $request->getParameters();
            $nrsoliserv = $param['NRSOLISERV'];
            $document = $param['DOCUMENT'];
            $this->soliservService->insertFileSpecificationTaskS($nrsoliserv, $document);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function editGridActivityS(Request $request, Response $response)
    {
        try{
            $params = $request->getParameters();
            foreach ($params['rowsSave'] as $param) {
                $cdfilial = $param['CDFILIAL'];
                $nrtarefa = $param['NRTAREFA'];
                $nrplativtare = $param['NRPLATIVTARE'];
                $nrprioativtr = $param['NRPRIOATIVTR'];
                $cdoperresp = $param['CDOPERRESP'];
                $qthrinfativtar = $param['QTHRINFATIVTAR'];
                $this->soliservService->editGridActivityS($cdfilial, $nrtarefa, $nrplativtare, $nrprioativtr,
                     $cdoperresp,$qthrinfativtar);
            }
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveTarefaSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params['rowsSave'] as $param) {
                $cdassunto = empty($param['CDASSUNTO']) ? null : $param['CDASSUNTO'];
                $cdoperresp = empty($param['CDOPERRESP']) ? null : $param['CDOPERRESP'];
                $dsrefetarefa = empty($param['DSREFETAREFA']) ? null : $param['DSREFETAREFA'];
                $idorigtare = empty($param['IDORIGTARE']) ? null : $param['IDORIGTARE'];
                $nrpriotarefa = empty($param['NRPRIOTAREFA']) ? null : $param['NRPRIOTAREFA'];
                $nrsoliserv = empty($param['NRSOLISERV']) ? null : $param['NRSOLISERV'];
                $this->soliservService->saveTarefaSoli($nrsoliserv, $cdassunto, $cdoperresp, $dsrefetarefa, $idorigtare, $nrpriotarefa);
            }

        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function editTarefaSoli(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();
            foreach ($params['rowsSave'] as $param) {
                $cdoperresp = empty($param['CDOPERRESP']) ? null : $param['CDOPERRESP'];
                $dsrefetarefa = empty($param['DSREFETAREFA']) ? null : $param['DSREFETAREFA'];
                $nrpriotarefa = empty($param['NRPRIOTAREFA']) ? null : $param['NRPRIOTAREFA'];
                $nrtarefa = empty($param['NRTAREFA']) ? null : $param['NRTAREFA'];
                $this->soliservService->editTarefaSoli($nrtarefa, $cdoperresp, $dsrefetarefa, $nrpriotarefa);
            }

        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
