# Zeedhi Queue #
_Adicionar o build status do jenkins._

## Descrição ##
O Zeedhi Queue é uma biblioteca para consumir e enviar mensagens usando o protocolo [STOMP](https://stomp.github.io/), 
para serviços de [message queue](http://en.wikipedia.org/wiki/Message_queue), por exemplo o 
[Apollo](http://activemq.apache.org/apollo/).


## Como Instalar ##
Adicione o nosso [repositório de pacotes](http://cdn.zeedhi.com/composer/), ao seu arquivo "composer.json", para mais 
detalhes [aqui](https://getcomposer.org/doc/04-schema.md#repositories)! 
```json
{
    "repositories": [
        {
            "type": "composer",
            "url": "http://cdn.zeedhi.com/composer"
        }
    ]
}
```
Rode o comando `composer require --dev zeedhi/queue:0.1.x-dev` no mesmo diretório onde se encontra o "composer.json" 
do seu projeto, para mais [detalhes](https://getcomposer.org/doc/03-cli.md#require). Ou adicione a linha 
`"zeedhi/queue": "0.1.x-dev"`, dentro da propriedade "require-dev" ao seu arquivo composer.json e rode o `composer update`.

## Uso Básico ##

_Para testar e ver funcionando na prática, você pode rodar os scripts `collector.php` e `producer.php` dentro da pasta
`examples`._

### Consumidor ###

A sua implementação de uma classe consumidora deve:
* dizer qual fila deve ser consumida. Sobrescrevendo o valor da variável estatica `$queueName`.
* implementar o método `public void consume(string $message)` definindo o que será executado quando uma nova mensagem 
for consumida. O parametro string vai possuir o corpo da mensagem, igual ao que foi enviado.
É importante saber que a parent class `\Zeedhi\Queue\Consumer` recebe uma instância de `\Zeedhi\Queue\Connection` no 
construtor, mesmo que você sobreescreva o construtor, o construtor original ainda deve ser chamado.

Exemplo de implementação de uma classe para consumir as mensagens. 
```php
<?php
namespace Acme;

class VarDumpConsumer extends \Zeedhi\Queue\Consumer{

    protected static $queueName = "/queue/var_dump";

    public function consume($message) {
        var_dump($message);
    }
}
```

Exemplo de um programa que roda a classe consumidora das acima.
```php
<?php
$consumer = new \Acme\VarDumpConsumer(
    new \Zeedhi\Queue\Connection(
        "127.0.0.1",
        "61613",
        "admin",
        "password",
        "mybroker"
    )
);

$consumer->run();
```

### Produtor ###

A sua implementação de uma classe produtora deve:
* dizer qual fila deve ser enviada as novas mensagens. Sobrescrevendo o valor da variável estatica `$queueName`.
É importante saber que a parent class `\Zeedhi\Queue\Producer` recebe uma instância de `\Zeedhi\Queue\Connection` no 
construtor, mesmo que você sobreescreva o construtor, o construtor original ainda deve ser chamado.

Exemplo de implementação de uma classe para enviar as mensagens.

```php
<?php
namespace Acme;

class VarDumpProducer extends \Zeedhi\Queue\Producer{

    protected static $queueName = "/queue/var_dump";

}
```

Exemplo de um programa que enviar mensagens através da classe.

```php
<?php
$producer = new \Acme\VarDumpProducer(
    new \Zeedhi\Queue\Connection(
        "127.0.0.1",
        "61613",
        "admin",
        "password",
        "mybroker"
    )
);

while(true) {
    $producer->send(trim(fgets(STDIN)));
}
```

## Uso Avançado ##

Para maiores detalhes leia o código do zeedhi/queue que é pequeno e a bibilioteca utilizada
[stomp-php](https://github.com/stomp-php/stomp-php). Vale lembrar que a partir deste commit a implementação é sincrona
por default.

## Erros Possíveis ##

* `"Missing queue name for Queue Consumer class {$consumerClass}."` : Sua classe de Consumidora da fila não declarou o 
valor do nome da fila. Favor declarar.
* `"Missing queue name for Queue Producer class {$producerClass}."` : Sua classe de Produtora da fila não declarou o 
valor do nome da fila. Favor declarar.
* `"Failed to send your data to queue"` : Não foi possível enviar seus dados a fila, por motivos diversos, tem que ser 
analizado e tratado cada caso em particular.

## FAQ ##
_OBS: Nenhuma pergunta foi feita ainda! Mas para realizar novas perguntas sugiro que crie uma 
["issue"](http://192.168.122.56/zeedhi/queue/issues) dentro do GitLab.

_
